Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1033)

Unified Diff: Source/core/editing/iterators/TextIterator.h

Issue 940373003: Rename RenderText to LayoutText (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/editing/iterators/TextIterator.h
diff --git a/Source/core/editing/iterators/TextIterator.h b/Source/core/editing/iterators/TextIterator.h
index df24609c662ecf6ffcbb34f58dc9aeb18cdb893a..589c0be00f366cd7366c95fce370203fd985bb11 100644
--- a/Source/core/editing/iterators/TextIterator.h
+++ b/Source/core/editing/iterators/TextIterator.h
@@ -36,8 +36,8 @@
namespace blink {
class InlineTextBox;
-class RenderText;
-class RenderTextFragment;
+class LayoutText;
+class LayoutTextFragment;
String plainText(const Range*, TextIteratorBehaviorFlags = TextIteratorDefaultBehavior);
String plainText(const Position& start, const Position& end, TextIteratorBehaviorFlags = TextIteratorDefaultBehavior);
@@ -133,10 +133,10 @@ private:
bool handleReplacedElement();
bool handleNonTextNode();
void handleTextBox();
- void handleTextNodeFirstLetter(RenderTextFragment*);
- bool hasVisibleTextNode(RenderText*);
+ void handleTextNodeFirstLetter(LayoutTextFragment*);
+ bool hasVisibleTextNode(LayoutText*);
void emitCharacter(UChar, Node* textNode, Node* offsetBaseNode, int textStartOffset, int textEndOffset);
- void emitText(Node* textNode, RenderText* renderer, int textStartOffset, int textEndOffset);
+ void emitText(Node* textNode, LayoutText* renderer, int textStartOffset, int textEndOffset);
// Current position, not necessarily of the text being returned, but position
// as we walk through the DOM tree.
@@ -168,8 +168,8 @@ private:
// Used when iteration over :first-letter text to save pointer to
// remaining text box.
InlineTextBox* m_remainingTextBox;
- // Used to point to RenderText object for :first-letter.
- RawPtrWillBeMember<RenderText> m_firstLetterText;
+ // Used to point to LayoutText object for :first-letter.
+ RawPtrWillBeMember<LayoutText> m_firstLetterText;
// Used to do the whitespace collapsing logic.
RawPtrWillBeMember<Text> m_lastTextNode;
« no previous file with comments | « Source/core/editing/iterators/SimplifiedBackwardsTextIterator.cpp ('k') | Source/core/editing/iterators/TextIterator.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698